@@ -17,7 +17,8 @@ from constants import (BREADTH_FIRST, DEPTH_FIRST,
                        RELATIONSHIP_RECENT, NONE,
                        NODE, RELATIONSHIP, PATH, POSITION,
                        INDEX_FULLTEXT, TX_GET, TX_PUT, TX_POST, TX_DELETE,
-                       RELATIONSHIPS_ALL, RELATIONSHIPS_IN, RELATIONSHIPS_OUT)
+                       RELATIONSHIPS_ALL, RELATIONSHIPS_IN, RELATIONSHIPS_OUT,
+                       RETURN_ALL_NODES, RETURN_ALL_BUT_START_NODE)
 from request import (Request, NotFoundError, StatusException,
                      TransactionException)
 
@@ -681,7 +682,7 @@ class Node(Base):
     Node class.
     """
 
-    def __getattr__(self, relationship_name, *args, **kwargs):
+    def __getattr__(self, *args, **kwargs):
         """
         HACK: Allow to set node relationship
         """
@@ -689,7 +690,9 @@ class Node(Base):
                       "relationships: n2.relationships.create(rel_name, n2). "
                       "This is needed in order to handle pickling in nodes.",
                       DeprecationWarning)
+        return self._create_relationship(*args, **kwargs)
 
+    def _create_relationship(self, relationship_name, *args, **kwargs):
         def relationship(to, *args, **kwargs):
             tx = Transaction.get_transaction(kwargs.get("tx", None))
             create_relationship_url = self._dic["create_relationship"]
@@ -743,6 +746,9 @@ class Node(Base):
         return int(self.url.split("/")[-1])
     id = property(_get_id)
 
+    def __hash__(self):
+        return hash(self.id)
+
     def traverse(self, types=None, order=None, stop=None, returnable=None,
                  uniqueness=None, is_stop_node=None, is_returnable=None,
                  paginated=False, page_size=None, time_out=None,
@@ -757,11 +763,16 @@ class Node(Base):
                 'language': 'javascript',
                 'body': 'false',
             }})
-        if returnable in (BREADTH_FIRST, DEPTH_FIRST):
+        if returnable in (RETURN_ALL_NODES, RETURN_ALL_BUT_START_NODE):
             data.update({"return_filter": {
                 "language": "builtin",
                 "name": returnable,
             }})
+        elif returnable:
+            data.update({"return_filter": {
+                "language": "javascript",
+                "body": returnable,
+            }})
         if uniqueness in (NODE_GLOBAL, NODE_PATH, NODE_RECENT, NODE,
                           RELATIONSHIP_GLOBAL, RELATIONSHIP_PATH,
                           RELATIONSHIP_RECENT, NONE):
@@ -805,9 +816,9 @@ class Node(Base):
                 elif returns == RELATIONSHIP:
                     return Iterable(Relationship, results_list, "self")
                 elif returns == PATH:
-                    return Iterable(Path, results_list)
+                    return Iterable(Path, results_list, "self")
                 elif returns == POSITION:
-                    return Iterable(Position, results_list)
+                    return Iterable(Position, results_list, "self")
             elif response.status == 404:
                 raise NotFoundError(response.status, "Node or relationship " \
                                                      "not found")
@@ -1230,7 +1241,7 @@ class Relationships(object):
     def create(self, relationship_name, to, **kwargs):
         # TODO: Improve the unicode checking
         try:
-            return getattr(self._node, relationship_name)(to, **kwargs)
+            return self._node._create_relationship(relationship_name)(to, **kwargs)
         except (KeyError, UnicodeEncodeError, UnicodeError):
             safe_name = smart_quote(relationship_name)
             return getattr(self._node, safe_name)(to, **kwargs)
@@ -1317,14 +1328,15 @@ class BaseInAndOut(object):
 
     def __init__(self, direction):
         self.direction = direction
-        if direction == "both":
-            warnings.warn("Deprecated, use \"All\" ('both') instead.",
-                          DeprecationWarning)
+       
 
     def get(self, attr):
         return self.__getattr__(attr)
 
     def __getattr__(self, attr):
+        if self.direction == "both":
+            warnings.warn("Deprecated, use \"All\" ('both') instead.",
+                          DeprecationWarning)
         # Using an anonymous class
         direction = self.direction
         return type("", (object, ), {
